<?php

namespace App\Notifications\Emails;

use Carbon\Carbon;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Illuminate\Support\Facades\Log;

use App\Models\Address;

class NodeDelisted extends Notification //implements ShouldQueue
{
	use Queueable;

	private const LOGKEY = 'NED';

	/**
	 * Create a new notification instance.
	 */
	public function __construct(private Address $ao)
	{
	}

	/**
	 * Get the notification's delivery channels.
	 *
	 * @return array<int, string>
	 */
	public function via(object $notifiable): array
	{
		return ['mail'];
	}

	/**
	 * Get the mail representation of the notification.
	 */
	public function toMail(object $notifiable): MailMessage
	{
		Log::info(sprintf('%s:+ Sending a NODE DELISTED EMAIL for address [%s]',self::LOGKEY,$this->ao->ftn));

		$now = Carbon::now();

		return (new MailMessage)
			->cc(our_address($this->ao)->system->users->first()->email)
			->subject(sprintf('Your system has been DE-LISTED on %s from %s',$now->format('Y-m-d'),$x=$this->ao->zone->domain->name))
			->line(sprintf('Your system has been DE-LISTED, because it hasnt polled **%s** with address %s since **%s** (%d days).',
				$x,
				$this->ao->ftn4d,
				$this->ao->system->last_seen?->format('Y-m-d') ?: 'Not seen',
				$this->ao->system->last_seen?->diffInDays($now)))
			->line('')
			->line('If you think this was a mistake, please let me know.')
			->line(sprintf('If you think about returning to %s, then reach out and we can get you back online pretty quickly.',$x));
	}
}